@@ -1,3 +1,3 @@
 from .requester import BaseAsyncRequester
 
-__all__ = ['BaseAsyncRequester']
+__all__ = ["BaseAsyncRequester"]
